summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/cpu/i860/i860dasm.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/cpu/i860/i860dasm.cpp')
-rw-r--r--src/devices/cpu/i860/i860dasm.cpp148
1 files changed, 74 insertions, 74 deletions
diff --git a/src/devices/cpu/i860/i860dasm.cpp b/src/devices/cpu/i860/i860dasm.cpp
index 60c83a5fec0..03d24e2d2a8 100644
--- a/src/devices/cpu/i860/i860dasm.cpp
+++ b/src/devices/cpu/i860/i860dasm.cpp
@@ -3,43 +3,43 @@
#include "i860.h"
/* Sub-group decoders */
-static void i860_dasm_core_dasm(const UINT32 op, char* buffer);
-static void i860_dasm_floating_point_dasm(const UINT32 op, char* buffer);
-static void i860_dasm_CTRL_dasm(const UINT32 op, char* buffer);
+static void i860_dasm_core_dasm(const uint32_t op, char* buffer);
+static void i860_dasm_floating_point_dasm(const uint32_t op, char* buffer);
+static void i860_dasm_CTRL_dasm(const uint32_t op, char* buffer);
/* REG-Format Opcodes*/
-static void i860_dasm_ldx(const UINT32 op, char* buffer);
-static void i860_dasm_stx(const UINT32 op, char* buffer);
-static void i860_dasm_ixfr(const UINT32 op, char* buffer);
-static void i860_dasm_fid_fst(const UINT32 op, char* buffer);
-static void i860_dasm_flush(const UINT32 op, char* buffer);
-static void i860_dasm_pstd(const UINT32 op, char* buffer);
-static void i860_dasm_ldc_sdc(const UINT32 op, char* buffer);
-static void i860_dasm_bri(const UINT32 op, char* buffer);
-static void i860_dasm_trap(const UINT32 op, char* buffer);
-static void i860_dasm_bte_btne(const UINT32 op, char* buffer);
-static void i860_dasm_pfidy(const UINT32 op, char* buffer);
-static void i860_dasm_addu_subu(const UINT32 op, char* buffer);
-static void i860_dasm_shl_shr(const UINT32 op, char* buffer);
-static void i860_dasm_shrd(const UINT32 op, char* buffer);
-static void i860_dasm_bla(const UINT32 op, char* buffer);
-static void i860_dasm_shra(const UINT32 op, char* buffer);
-static void i860_dasm_and_andh(const UINT32 op, char* buffer);
-static void i860_dasm_andnot_andnoth(const UINT32 op, char* buffer);
-static void i860_dasm_or_orh(const UINT32 op, char* buffer);
-static void i860_dasm_xor_xorh(const UINT32 op, char* buffer);
+static void i860_dasm_ldx(const uint32_t op, char* buffer);
+static void i860_dasm_stx(const uint32_t op, char* buffer);
+static void i860_dasm_ixfr(const uint32_t op, char* buffer);
+static void i860_dasm_fid_fst(const uint32_t op, char* buffer);
+static void i860_dasm_flush(const uint32_t op, char* buffer);
+static void i860_dasm_pstd(const uint32_t op, char* buffer);
+static void i860_dasm_ldc_sdc(const uint32_t op, char* buffer);
+static void i860_dasm_bri(const uint32_t op, char* buffer);
+static void i860_dasm_trap(const uint32_t op, char* buffer);
+static void i860_dasm_bte_btne(const uint32_t op, char* buffer);
+static void i860_dasm_pfidy(const uint32_t op, char* buffer);
+static void i860_dasm_addu_subu(const uint32_t op, char* buffer);
+static void i860_dasm_shl_shr(const uint32_t op, char* buffer);
+static void i860_dasm_shrd(const uint32_t op, char* buffer);
+static void i860_dasm_bla(const uint32_t op, char* buffer);
+static void i860_dasm_shra(const uint32_t op, char* buffer);
+static void i860_dasm_and_andh(const uint32_t op, char* buffer);
+static void i860_dasm_andnot_andnoth(const uint32_t op, char* buffer);
+static void i860_dasm_or_orh(const uint32_t op, char* buffer);
+static void i860_dasm_xor_xorh(const uint32_t op, char* buffer);
/* CORE Escape Opcodes */
-static void i860_dasm_CORE_lock(const UINT32 op, char* buffer);
-static void i860_dasm_CORE_calli(const UINT32 op, char* buffer);
-static void i860_dasm_CORE_intovr(const UINT32 op, char* buffer);
-static void i860_dasm_CORE_unlock(const UINT32 op, char* buffer);
+static void i860_dasm_CORE_lock(const uint32_t op, char* buffer);
+static void i860_dasm_CORE_calli(const uint32_t op, char* buffer);
+static void i860_dasm_CORE_intovr(const uint32_t op, char* buffer);
+static void i860_dasm_CORE_unlock(const uint32_t op, char* buffer);
/* CTRL-Format Opcodes */
-static void i860_dasm_CTRL_br(const UINT32 op, char* buffer);
-static void i860_dasm_CTRL_call(const UINT32 op, char* buffer);
-static void i860_dasm_CTRL_bc_bct(const UINT32 op, char* buffer);
-static void i860_dasm_CTRL_bnc_bnct(const UINT32 op, char* buffer);
+static void i860_dasm_CTRL_br(const uint32_t op, char* buffer);
+static void i860_dasm_CTRL_call(const uint32_t op, char* buffer);
+static void i860_dasm_CTRL_bc_bct(const uint32_t op, char* buffer);
+static void i860_dasm_CTRL_bnc_bnct(const uint32_t op, char* buffer);
/* Floating-Point Instructions */
@@ -49,13 +49,13 @@ CPU_DISASSEMBLE( i860 )
char tempB[1024] = "";
/* Little Endian */
- const UINT32 op = (oprom[3] << 24) | (oprom[2] << 16) | (oprom[1] << 8) | (oprom[0] << 0);
- //const UINT32 op = (oprom[2] << 24) | (oprom[3] << 16) | (oprom[0] << 8) | (oprom[1] << 0); /* Mixed Endian */
- //const UINT32 op = (oprom[0] << 24) | (oprom[1] << 16) | (oprom[2] << 8) | (oprom[3] << 0); /* Big Endian */
- //const UINT32 op = (oprom[1] << 24) | (oprom[0] << 16) | (oprom[3] << 8) | (oprom[2] << 0); /* Mixed Endian */
+ const uint32_t op = (oprom[3] << 24) | (oprom[2] << 16) | (oprom[1] << 8) | (oprom[0] << 0);
+ //const uint32_t op = (oprom[2] << 24) | (oprom[3] << 16) | (oprom[0] << 8) | (oprom[1] << 0); /* Mixed Endian */
+ //const uint32_t op = (oprom[0] << 24) | (oprom[1] << 16) | (oprom[2] << 8) | (oprom[3] << 0); /* Big Endian */
+ //const uint32_t op = (oprom[1] << 24) | (oprom[0] << 16) | (oprom[3] << 8) | (oprom[2] << 0); /* Mixed Endian */
/* The opcode is the top 6 bits */
- UINT8 opcode = (op >> 26) & 0x3f;
+ uint8_t opcode = (op >> 26) & 0x3f;
/* DEBUG - print this out if you feel things are going a bit wonky */
// sprintf(buffer, "%08x : oo %02x", op, opcode);
@@ -172,9 +172,9 @@ CPU_DISASSEMBLE( i860 )
/**********************/
/* Sub-group decoders */
/**********************/
-static void i860_dasm_core_dasm(const UINT32 op, char* buffer)
+static void i860_dasm_core_dasm(const uint32_t op, char* buffer)
{
- //UINT8 src1 = (op >> 11) & 0x0000001f;
+ //uint8_t src1 = (op >> 11) & 0x0000001f;
/* Reserved bits must be set to 0 */
if ( (op & 0x000007e0) || (op & 0x03ff0000) )
@@ -194,14 +194,14 @@ static void i860_dasm_core_dasm(const UINT32 op, char* buffer)
}
}
-static void i860_dasm_floating_point_dasm(const UINT32 op, char* buffer)
+static void i860_dasm_floating_point_dasm(const uint32_t op, char* buffer)
{
sprintf(buffer, "[[F-P unit]]");
}
-static void i860_dasm_CTRL_dasm(const UINT32 op, char* buffer)
+static void i860_dasm_CTRL_dasm(const uint32_t op, char* buffer)
{
- UINT8 opc = (op >> 26) & 0x07;
+ uint8_t opc = (op >> 26) & 0x07;
switch(opc)
{
@@ -218,108 +218,108 @@ static void i860_dasm_CTRL_dasm(const UINT32 op, char* buffer)
/*********************/
/* REG-Format Opcodes*/
/*********************/
-static void i860_dasm_ldx(const UINT32 op, char* buffer)
+static void i860_dasm_ldx(const uint32_t op, char* buffer)
{
sprintf(buffer, "ldx");
}
-static void i860_dasm_stx(const UINT32 op, char* buffer)
+static void i860_dasm_stx(const uint32_t op, char* buffer)
{
sprintf(buffer, "stx");
}
-static void i860_dasm_ixfr(const UINT32 op, char* buffer)
+static void i860_dasm_ixfr(const uint32_t op, char* buffer)
{
-// UINT16 val = op & 0x7ff;
-// UINT8 opc = (op >> 26) & 0x3f;
-// UINT8 src2 = (op >> 21) & 0x1f;
-// UINT8 dest = (op >> 16) & 0x1f;
-// UINT8 src1 = (op >> 11) & 0x1f;
+// uint16_t val = op & 0x7ff;
+// uint8_t opc = (op >> 26) & 0x3f;
+// uint8_t src2 = (op >> 21) & 0x1f;
+// uint8_t dest = (op >> 16) & 0x1f;
+// uint8_t src1 = (op >> 11) & 0x1f;
sprintf(buffer, "ixfr");
}
-static void i860_dasm_fid_fst(const UINT32 op, char* buffer)
+static void i860_dasm_fid_fst(const uint32_t op, char* buffer)
{
sprintf(buffer, "fst");
}
-static void i860_dasm_flush(const UINT32 op, char* buffer)
+static void i860_dasm_flush(const uint32_t op, char* buffer)
{
sprintf(buffer, "flush");
}
-static void i860_dasm_pstd(const UINT32 op, char* buffer)
+static void i860_dasm_pstd(const uint32_t op, char* buffer)
{
sprintf(buffer, "pstd");
}
-static void i860_dasm_ldc_sdc(const UINT32 op, char* buffer)
+static void i860_dasm_ldc_sdc(const uint32_t op, char* buffer)
{
sprintf(buffer, "ldc, sdc");
}
-static void i860_dasm_bri(const UINT32 op, char* buffer)
+static void i860_dasm_bri(const uint32_t op, char* buffer)
{
sprintf(buffer, "bri");
}
-static void i860_dasm_trap(const UINT32 op, char* buffer)
+static void i860_dasm_trap(const uint32_t op, char* buffer)
{
sprintf(buffer, "trap");
}
-static void i860_dasm_bte_btne(const UINT32 op, char* buffer)
+static void i860_dasm_bte_btne(const uint32_t op, char* buffer)
{
sprintf(buffer, "bte, btne");
}
-static void i860_dasm_pfidy(const UINT32 op, char* buffer)
+static void i860_dasm_pfidy(const uint32_t op, char* buffer)
{
sprintf(buffer, "pfidy");
}
-static void i860_dasm_addu_subu(const UINT32 op, char* buffer)
+static void i860_dasm_addu_subu(const uint32_t op, char* buffer)
{
sprintf(buffer, "addu, subu");
}
-static void i860_dasm_shl_shr(const UINT32 op, char* buffer)
+static void i860_dasm_shl_shr(const uint32_t op, char* buffer)
{
sprintf(buffer, "shl, shr");
}
-static void i860_dasm_shrd(const UINT32 op, char* buffer)
+static void i860_dasm_shrd(const uint32_t op, char* buffer)
{
sprintf(buffer, "shrd");
}
-static void i860_dasm_bla(const UINT32 op, char* buffer)
+static void i860_dasm_bla(const uint32_t op, char* buffer)
{
sprintf(buffer, "bla");
}
-static void i860_dasm_shra(const UINT32 op, char* buffer)
+static void i860_dasm_shra(const uint32_t op, char* buffer)
{
sprintf(buffer, "shra");
}
-static void i860_dasm_and_andh(const UINT32 op, char* buffer)
+static void i860_dasm_and_andh(const uint32_t op, char* buffer)
{
sprintf(buffer, "and, andh");
}
-static void i860_dasm_andnot_andnoth(const UINT32 op, char* buffer)
+static void i860_dasm_andnot_andnoth(const uint32_t op, char* buffer)
{
sprintf(buffer, "andnot, andnoth");
}
-static void i860_dasm_or_orh(const UINT32 op, char* buffer)
+static void i860_dasm_or_orh(const uint32_t op, char* buffer)
{
sprintf(buffer, "or, orh");
}
-static void i860_dasm_xor_xorh(const UINT32 op, char* buffer)
+static void i860_dasm_xor_xorh(const uint32_t op, char* buffer)
{
sprintf(buffer, "xor, xorh");
}
@@ -328,22 +328,22 @@ static void i860_dasm_xor_xorh(const UINT32 op, char* buffer)
/***********************/
/* CORE Escape Opcodes */
/***********************/
-static void i860_dasm_CORE_lock(const UINT32 op, char* buffer)
+static void i860_dasm_CORE_lock(const uint32_t op, char* buffer)
{
sprintf(buffer, "lock");
}
-static void i860_dasm_CORE_calli(const UINT32 op, char* buffer)
+static void i860_dasm_CORE_calli(const uint32_t op, char* buffer)
{
sprintf(buffer, "calli");
}
-static void i860_dasm_CORE_intovr(const UINT32 op, char* buffer)
+static void i860_dasm_CORE_intovr(const uint32_t op, char* buffer)
{
sprintf(buffer, "intovr");
}
-static void i860_dasm_CORE_unlock(const UINT32 op, char* buffer)
+static void i860_dasm_CORE_unlock(const uint32_t op, char* buffer)
{
sprintf(buffer, "unlock");
}
@@ -352,22 +352,22 @@ static void i860_dasm_CORE_unlock(const UINT32 op, char* buffer)
/***********************/
/* CTRL-Format Opcodes */
/***********************/
-static void i860_dasm_CTRL_br(const UINT32 op, char* buffer)
+static void i860_dasm_CTRL_br(const uint32_t op, char* buffer)
{
sprintf(buffer, "br");
}
-static void i860_dasm_CTRL_call(const UINT32 op, char* buffer)
+static void i860_dasm_CTRL_call(const uint32_t op, char* buffer)
{
sprintf(buffer, "call");
}
-static void i860_dasm_CTRL_bc_bct(const UINT32 op, char* buffer)
+static void i860_dasm_CTRL_bc_bct(const uint32_t op, char* buffer)
{
sprintf(buffer, "bct");
}
-static void i860_dasm_CTRL_bnc_bnct(const UINT32 op, char* buffer)
+static void i860_dasm_CTRL_bnc_bnct(const uint32_t op, char* buffer)
{
sprintf(buffer, "bnct");
}